@@ -218,7 +218,7 @@ ext_demos(struct notcurses* nc, const char* spec, bool ignore_failures){
     // set the standard plane's base character to an opaque black, but don't
     // erase the plane (we let one demo bleed through to the next, an effect
     // we exploit in a few transitions).
-    cell c = CELL_TRIVIAL_INITIALIZER;
+    nccell c = CELL_TRIVIAL_INITIALIZER;
     cell_set_fg_rgb8(&c, 0, 0, 0);
     cell_set_bg_rgb8(&c, 0, 0, 0);
     ncplane_set_base_cell(n, &c);
