@@ -60,7 +60,7 @@ struct esctrie;
 // circular buffer of rows. 'logrow' is the index of the row at the logical top
 // of the plane. It only changes from 0 if the plane is scrollable.
 typedef struct ncplane {
-  cell* fb;              // "framebuffer" of character cells
+  nccell* fb;            // "framebuffer" of character cells
   int logrow;            // logical top row, starts at 0, add one for each scroll
   int x, y;              // current cursor location within this plane
   // ncplane_yx() etc. use coordinates relative to the plane to which this
@@ -68,23 +68,27 @@ typedef struct ncplane {
   // they must thus be translated by any function which moves a parent plane.
   int absx, absy;        // origin of the plane relative to the screen
   int lenx, leny;        // size of the plane, [0..len{x,y}) is addressable
-  // a notcurses context is made up of stacks, each rooted by a plane which is
-  // bound to no other plane. the main stack is rooted by the standard plane,
-  // and is the only stack which is rendered. each stack has its own z-axis.
-  struct ncplane* above; // plane above us, NULL if we're on top
-  struct ncplane* below; // plane below us, NULL if we're on bottom
-  struct ncplane* bnext; // next in the blist iff we're bound, NULL otherwise
-  struct ncplane** bprev;// blist link to us iff we're bound, NULL otherwise
-  struct ncplane* blist; // head of list of bound planes
-  // a root plane is bound to itself. every other plane has a path to its
-  // stack's root via boundto. the standard plane is always bound to itself.
-  struct ncplane* boundto;
   egcpool pool;          // attached storage pool for UTF-8 EGCs
   uint64_t channels;     // works the same way as cells
+
+  // a notcurses context is made up of piles, each rooted by one or more root
+  // planes. each pile has its own (totally ordered) z-axis.
+  struct ncpile* pile;   // pile of which we are a part
+  struct ncplane* above; // plane above us, NULL if we're on top
+  struct ncplane* below; // plane below us, NULL if we're on bottom
+
+  // every plane is bound to some other plane, unless it is a root plane of a
+  // pile. a pile has a set of one or more root planes, all of them siblings.
+  // root planes are bound to themselves. the standard plane is always a root
+  // plane (since it cannot be reparented). a path exists to a root plane.
+  struct ncplane* bnext;  // next in the blist
+  struct ncplane** bprev; // blist link back to us
+  struct ncplane* blist;  // head of list of bound planes
+  struct ncplane* boundto;// plane to which we are bound (ourself for roots)
+
   void* userptr;         // slot for the user to stick some opaque pointer
   int (*resizecb)(struct ncplane*); // callback after parent is resized
-  cell basecell;         // cell written anywhere that fb[i].gcluster == 0
-  struct ncpile* pile;   // pile of which we are a part
+  nccell basecell;       // cell written anywhere that fb[i].gcluster == 0
   char* name;            // used only for debugging
   ncalign_e align;       // relative to parent plane, for automatic realignment
   uint16_t stylemask;    // same deal as in a cell
@@ -303,6 +307,7 @@ typedef struct ncdirect {
 typedef struct ncpile {
   ncplane* top;               // topmost plane, never NULL
   ncplane* bottom;            // bottommost plane, never NULL
+  ncplane* roots;             // head of root plane list
   struct notcurses* nc;       // notcurses context
   struct ncpile *prev, *next; // circular list
   int dimy, dimx;             // rows and cols at time of render
@@ -318,7 +323,7 @@ typedef struct notcurses {
 
   // we keep a copy of the last rendered frame. this facilitates O(1)
   // notcurses_at_yx() and O(1) damage detection (at the cost of some memory).
-  cell* lastframe;// last rasterized framebuffer, NULL until first rasterization
+  nccell* lastframe;// last rasterized framebuffer, NULL until first raster
   egcpool pool;   // egcpool for lastframe
 
   int lfdimx;     // dimensions of lastframe, unchanged by screen resize
@@ -330,9 +335,6 @@ typedef struct notcurses {
   ncstats stats;  // some statistics across the lifetime of the notcurses ctx
   ncstats stashstats; // cumulative stats, unaffected by notcurses_stats_reset()
 
-  int truecols;   // true number of columns in the physical rendering area.
-                  // used only to see if output motion takes us to the next
-                  // line thanks to terminal action alone.
   FILE* ttyfp;    // FILE* for writing rasterized data
   int ttyfd;      // file descriptor for controlling tty
   ncinputlayer input; // input layer; we're in cbreak mode
@@ -353,10 +355,12 @@ typedef struct notcurses {
 
 void sigwinch_handler(int signo);
 
-void init_lang(struct notcurses* nc); // nc may be NULL, only used for logging
+void init_lang(notcurses* nc); // nc may be NULL, only used for logging
 int terminfostr(char** gseq, const char* name);
 int interrogate_terminfo(tinfo* ti);
 
+int resize_callbacks_children(ncplane* n);
+
 // Search the provided multibyte (UTF8) string 's' for the provided unicode
 // codepoint 'cp'. If found, return the column offset of the EGC in which the
 // codepoint appears in 'col', and the byte offset as the return value. If not
@@ -573,22 +577,20 @@ term_fg_palindex(const notcurses* nc, FILE* out, unsigned pal){
 }
 
 static inline const char*
-pool_extended_gcluster(const egcpool* pool, const cell* c){
+pool_extended_gcluster(const egcpool* pool, const nccell* c){
   if(cell_simple_p(c)){
     return (const char*)&c->gcluster;
   }
   return egcpool_extended_gcluster(pool, c);
 }
 
-static inline cell*
+static inline nccell*
 ncplane_cell_ref_yx(ncplane* n, int y, int x){
-  assert(y < n->leny);
-  assert(x < n->lenx);
   return &n->fb[nfbcellidx(n, y, x)];
 }
 
 static inline void
-cell_set_wide(cell* c){
+cell_set_wide(nccell* c){
   c->channels |= CELL_WIDEASIAN_MASK;
 }
 
@@ -607,7 +609,7 @@ ns_to_timespec(uint64_t ns, struct timespec* ts){
 }
 
 static inline void
-cell_debug(const egcpool* p, const cell* c){
+cell_debug(const egcpool* p, const nccell* c){
   fprintf(stderr, "gcluster: %u %s style: 0x%04x chan: 0x%016jx\n",
 				  c->gcluster, egcpool_extended_gcluster(p, c), c->stylemask, c->channels);
 }
@@ -620,7 +622,7 @@ plane_debug(const ncplane* n, bool details){
   if(details){
     for(int y = 0 ; y < 1 ; ++y){
       for(int x = 0 ; x < 10 ; ++x){
-        const cell* c = &n->fb[fbcellidx(y, dimx, x)];
+        const nccell* c = &n->fb[fbcellidx(y, dimx, x)];
         fprintf(stderr, "[%03d/%03d] ", y, x);
         cell_debug(&n->pool, c);
       }
@@ -629,30 +631,30 @@ plane_debug(const ncplane* n, bool details){
 }
 
 static inline void
-pool_release(egcpool* pool, cell* c){
+pool_release(egcpool* pool, nccell* c){
   if(!cell_simple_p(c)){
     egcpool_release(pool, cell_egc_idx(c));
   }
   c->gcluster = 0; // don't subject ourselves to double-release problems
 }
 
-// set the cell 'c' to point into the egcpool at location 'eoffset'
+// set the nccell 'c' to point into the egcpool at location 'eoffset'
 static inline void
-set_gcluster_egc(cell* c, int eoffset){
+set_gcluster_egc(nccell* c, int eoffset){
   c->gcluster = htole(0x01000000ul) + htole(eoffset);
 }
 
-// Duplicate one cell onto another, possibly crossing ncplanes.
+// Duplicate one nccell onto another, possibly crossing ncplanes.
 static inline int
-cell_duplicate_far(egcpool* tpool, cell* targ, const ncplane* splane, const cell* c){
+cell_duplicate_far(egcpool* tpool, nccell* targ, const ncplane* splane, const nccell* c){
   pool_release(tpool, targ);
   targ->stylemask = c->stylemask;
   targ->channels = c->channels;
+  targ->width = c->width;
   if(cell_simple_p(c)){
     targ->gcluster = c->gcluster;
     return 0;
   }
-  assert(splane);
   const char* egc = cell_extended_gcluster(splane, c);
   // FIXME we could eliminate this strlen() with a cell_extended_gcluster_len()
   // that returned the length, combined with O(1) length for inlined EGCs...
@@ -738,10 +740,6 @@ int ncvisual_bounding_box(const struct ncvisual* ncv, int* leny, int* lenx,
 static int
 calc_gradient_component(unsigned tl, unsigned tr, unsigned bl, unsigned br,
                         int y, int x, int ylen, int xlen){
-  assert(y >= 0);
-  assert(y < ylen);
-  assert(x >= 0);
-  assert(x < xlen);
   const int avm = (ylen - 1) - y;
   const int ahm = (xlen - 1) - x;
   if(xlen < 2){
@@ -880,7 +878,7 @@ box_corner_needs(unsigned ctlword){
 // True if the cell does not generate background pixels (i.e., the cell is a
 // solid or shaded block, or certain emoji).
 static inline bool
-cell_nobackground_p(const cell* c){
+cell_nobackground_p(const nccell* c){
   return c->channels & CELL_NOBACKGROUND_MASK;
 }
 
@@ -923,12 +921,12 @@ channels_blend(unsigned c1, unsigned c2, unsigned* blends){
 
 // do not pass palette-indexed channels!
 static inline uint64_t
-cell_blend_fchannel(cell* cl, unsigned channel, unsigned* blends){
+cell_blend_fchannel(nccell* cl, unsigned channel, unsigned* blends){
   return cell_set_fchannel(cl, channels_blend(cell_fchannel(cl), channel, blends));
 }
 
 static inline uint64_t
-cell_blend_bchannel(cell* cl, unsigned channel, unsigned* blends){
+cell_blend_bchannel(nccell* cl, unsigned channel, unsigned* blends){
   return cell_set_bchannel(cl, channels_blend(cell_bchannel(cl), channel, blends));
 }
 
@@ -963,7 +961,7 @@ egc_rtl(const char* egc, int* bytes){
 // CELL_WIDEASIAN_MASK and CELL_NOBACKGROUND_MASK ought be set however they're
 // going to be set.
 static inline int
-pool_blit_direct(egcpool* pool, cell* c, const char* gcluster, int bytes, int cols){
+pool_blit_direct(egcpool* pool, nccell* c, const char* gcluster, int bytes, int cols){
   pool_release(pool, c);
   if(bytes < 0 || cols < 0){
     return -1;
@@ -982,8 +980,9 @@ pool_blit_direct(egcpool* pool, cell* c, const char* gcluster, int bytes, int co
 }
 
 static inline int
-pool_load_direct(egcpool* pool, cell* c, const char* gcluster, int bytes, int cols){
+pool_load_direct(egcpool* pool, nccell* c, const char* gcluster, int bytes, int cols){
   char* rtl = NULL;
+  c->width = cols - 1;
   if(cols < 2){
     c->channels &= ~CELL_WIDEASIAN_MASK;
     if(bytes == 3 && memcmp(gcluster, "\xe2\x96\x88", 4) == 0){
@@ -1007,12 +1006,12 @@ pool_load_direct(egcpool* pool, cell* c, const char* gcluster, int bytes, int co
 }
 
 static inline int
-cell_load_direct(ncplane* n, cell* c, const char* gcluster, int bytes, int cols){
+cell_load_direct(ncplane* n, nccell* c, const char* gcluster, int bytes, int cols){
   return pool_load_direct(&n->pool, c, gcluster, bytes, cols);
 }
 
 static inline int
-pool_load(egcpool* pool, cell* c, const char* gcluster){
+pool_load(egcpool* pool, nccell* c, const char* gcluster){
   int cols;
   int bytes = utf8_egc_len(gcluster, &cols);
   return pool_load_direct(pool, c, gcluster, bytes, cols);
@@ -1038,12 +1037,12 @@ iswordbreak(wchar_t wchar){
   return uc_is_general_category_withtable(wchar, mask);
 }
 
-// the heart of damage detection. compare two cells (from two different planes)
-// for equality. if they are equal, return 0. otherwise, dup the second onto
-// the first and return non-zero.
+// the heart of damage detection. compare two nccells (from two different
+// planes) for equality. if they are equal, return 0. otherwise, dup the second
+// onto the first and return non-zero.
 static inline int
-cellcmp_and_dupfar(egcpool* dampool, cell* damcell,
-                   const ncplane* srcplane, const cell* srccell){
+cellcmp_and_dupfar(egcpool* dampool, nccell* damcell,
+                   const ncplane* srcplane, const nccell* srccell){
   if(damcell->stylemask == srccell->stylemask){
     if(damcell->channels == srccell->channels){
       const char* srcegc = cell_extended_gcluster(srcplane, srccell);
