@@ -23,6 +23,12 @@
 
 #define ESC "\x1b"
 
+// there does not exist any true standard terminal size. with that said, we
+// need assume *something* for the case where we're not actually attached to
+// a terminal (mainly unit tests, but also daemon environments).
+static const int DEFAULT_ROWS = 24;
+static const int DEFAULT_COLS = 80;
+
 void notcurses_version_components(int* major, int* minor, int* patch, int* tweak){
   *major = NOTCURSES_VERNUM_MAJOR;
   *minor = NOTCURSES_VERNUM_MINOR;
@@ -239,10 +245,12 @@ void ncplane_dim_yx(const ncplane* n, int* rows, int* cols){
 }
 
 // anyone calling this needs ensure the ncplane's framebuffer is updated
-// to reflect changes in geometry.
+// to reflect changes in geometry. also called at startup for standard plane.
 int update_term_dimensions(int fd, int* rows, int* cols){
   // if we're not a real tty, we presumably haven't changed geometry, return
   if(fd < 0){
+    *rows = DEFAULT_ROWS;
+    *cols = DEFAULT_COLS;
     return 0;
   }
   struct winsize ws;
@@ -304,7 +312,9 @@ make_ncpile(notcurses* nc, ncplane* n){
     ret->nc = nc;
     ret->top = n;
     ret->bottom = n;
-    if(nc->stdplane){
+    ret->roots = n;
+    n->bprev = &ret->roots;
+    if(nc->stdplane){ // stdplane (and thus stdpile) has already been created
       ret->prev = ncplane_pile(nc->stdplane)->prev;
       ncplane_pile(nc->stdplane)->prev->next = ret;
       ret->next = ncplane_pile(nc->stdplane);
@@ -429,7 +439,10 @@ create_initial_ncplane(notcurses* nc, int dimy, int dimx){
     .x = nc->margin_l,
     .rows = dimy - (nc->margin_t + nc->margin_b),
     .cols = dimx - (nc->margin_l + nc->margin_r),
+    .userptr = NULL,
     .name = "std",
+    .resizecb = ncplane_resize_maximize,
+    .flags = 0,
   };
   return nc->stdplane = ncplane_new_internal(nc, NULL, &nopts);
 }
@@ -540,8 +553,7 @@ ncplane* ncplane_dup(const ncplane* n, void* opaque){
 // call the resize callback for each bound child in turn. we only need to do
 // the first generation; if they resize, they'll invoke
 // ncplane_resize_internal(), leading to this function being called anew.
-static int
-resize_children(ncplane* n){
+int resize_callbacks_children(ncplane* n){
   int ret = 0;
   for(struct ncplane* child = n->blist ; child ; child = child->bnext){
     if(child->resizecb){
@@ -585,8 +597,8 @@ int ncplane_resize_internal(ncplane* n, int keepy, int keepx, int keepleny,
   // we've shrunk, we will be filling the new structure.
   int keptarea = keepleny * keeplenx;
   int newarea = ylen * xlen;
-  size_t fbsize = sizeof(cell) * newarea;
-  cell* fb = malloc(fbsize);
+  size_t fbsize = sizeof(nccell) * newarea;
+  nccell* fb = malloc(fbsize);
   if(fb == NULL){
     return -1;
   }
@@ -597,7 +609,7 @@ int ncplane_resize_internal(ncplane* n, int keepy, int keepx, int keepleny,
   if(n->x >= xlen){
     n->x = xlen - 1;
   }
-  cell* preserved = n->fb;
+  nccell* preserved = n->fb;
   ncplane_notcurses(n)->stats.fbbytes -= sizeof(*preserved) * (rows * cols);
   ncplane_notcurses(n)->stats.fbbytes += fbsize;
   n->fb = fb;
@@ -616,7 +628,7 @@ int ncplane_resize_internal(ncplane* n, int keepy, int keepx, int keepleny,
     n->lenx = xlen;
     n->leny = ylen;
     free(preserved);
-    return resize_children(n);
+    return resize_callbacks_children(n);
   }
   // we currently have maxy rows of maxx cells each. we will be keeping rows
   // keepy..keepy + keepleny - 1 and columns keepx..keepx + keeplenx - 1.
@@ -652,7 +664,7 @@ int ncplane_resize_internal(ncplane* n, int keepy, int keepx, int keepleny,
   n->lenx = xlen;
   n->leny = ylen;
   free(preserved);
-  return resize_children(n);
+  return resize_callbacks_children(n);
 }
 
 int ncplane_resize(ncplane* n, int keepy, int keepx, int keepleny,
@@ -821,7 +833,7 @@ init_banner(const notcurses* nc){
            "  compiled with gcc-%s, %s-endian\n"
            "  terminfo from %s\n",
            nc->stdplane->leny, nc->stdplane->lenx,
-           bprefix(nc->stats.fbbytes, 1, prefixbuf, 0), sizeof(cell),
+           bprefix(nc->stats.fbbytes, 1, prefixbuf, 0), sizeof(nccell),
            nc->tcache.colors, nc->tcache.RGBflag ? "+RGB" : "",
            __VERSION__,
 #ifdef __BYTE_ORDER__
@@ -921,7 +933,7 @@ get_tty_fd(notcurses* nc, FILE* ttyfp){
   if(fd < 0){
     fd = open("/dev/tty", O_RDWR | O_CLOEXEC);
     if(fd < 0){
-      logwarn(nc, "Error opening /dev/tty (%s)\n", strerror(errno));
+      loginfo(nc, "Error opening /dev/tty (%s)\n", strerror(errno));
     }
   }
   return fd;
@@ -1059,6 +1071,8 @@ notcurses* notcurses_init(const notcurses_options* opts, FILE* outfp){
       free(ret);
       return NULL;
     }
+  }else{
+    fprintf(stderr, "Defaulting to %dx%d (output is not to a terminal)\n", DEFAULT_ROWS, DEFAULT_COLS);
   }
   if(setup_signals(ret,
                    (opts->flags & NCOPTION_NO_QUIT_SIGHANDLERS),
@@ -1072,14 +1086,8 @@ notcurses* notcurses_init(const notcurses_options* opts, FILE* outfp){
     goto err;
   }
   int dimy, dimx;
-  if(ret->ttyfd >= 0){
-    if(update_term_dimensions(ret->ttyfd, &dimy, &dimx)){
-      goto err;
-    }
-  }else{
-    dimy = 24; // fuck it, lol
-    dimx = 80;
-    fprintf(stderr, "Defaulting to %dx%d (output is not to a terminal)\n", dimy, dimx);
+  if(update_term_dimensions(ret->ttyfd, &dimy, &dimx)){
+    goto err;
   }
   ret->suppress_banner = opts->flags & NCOPTION_SUPPRESS_BANNERS;
   char* shortname_term = termname();
@@ -1089,7 +1097,6 @@ notcurses* notcurses_init(const notcurses_options* opts, FILE* outfp){
             shortname_term ? shortname_term : "?",
             longname_term ? longname_term : "?");
   }
-  ret->truecols = dimx;
   if(interrogate_terminfo(&ret->tcache)){
     goto err;
   }
@@ -1346,7 +1353,7 @@ int ncplane_set_bg_palindex(ncplane* n, int idx){
   return 0;
 }
 
-int ncplane_set_base_cell(ncplane* ncp, const cell* c){
+int ncplane_set_base_cell(ncplane* ncp, const nccell* c){
   return cell_duplicate(ncp, &ncp->basecell, c);
 }
 
@@ -1354,11 +1361,11 @@ int ncplane_set_base(ncplane* ncp, const char* egc, uint32_t stylemask, uint64_t
   return cell_prime(ncp, &ncp->basecell, egc, stylemask, channels);
 }
 
-int ncplane_base(ncplane* ncp, cell* c){
+int ncplane_base(ncplane* ncp, nccell* c){
   return cell_duplicate(ncp, c, &ncp->basecell);
 }
 
-const char* cell_extended_gcluster(const ncplane* n, const cell* c){
+const char* cell_extended_gcluster(const ncplane* n, const nccell* c){
   if(cell_simple_p(c)){
     return (const char*)&c->gcluster;
   }
@@ -1466,7 +1473,7 @@ void ncplane_cursor_yx(const ncplane* n, int* y, int* x){
 }
 
 static inline void
-cell_obliterate(ncplane* n, cell* c){
+cell_obliterate(ncplane* n, nccell* c){
   cell_release(n, c);
   cell_init(c);
 }
@@ -1476,7 +1483,7 @@ void scroll_down(ncplane* n){
   n->x = 0;
   if(n->y == n->leny - 1){
     n->logrow = (n->logrow + 1) % n->leny;
-    cell* row = n->fb + nfbcellidx(n, n->y, 0);
+    nccell* row = n->fb + nfbcellidx(n, n->y, 0);
     for(int clearx = 0 ; clearx < n->lenx ; ++clearx){
       cell_release(n, &row[clearx]);
     }
@@ -1486,7 +1493,7 @@ void scroll_down(ncplane* n){
   }
 }
 
-int cell_load(ncplane* n, cell* c, const char* gcluster){
+int cell_load(ncplane* n, nccell* c, const char* gcluster){
   return pool_load(&n->pool, c, gcluster);
 }
 
@@ -1530,10 +1537,10 @@ ncplane_put(ncplane* n, int y, int x, const char* egc, int cols,
   // that cell as wide). Any character placed atop one half of a wide character
   // obliterates the other half. Note that a wide char can thus obliterate two
   // wide chars, totalling four columns.
-  cell* targ = ncplane_cell_ref_yx(n, n->y, n->x);
+  nccell* targ = ncplane_cell_ref_yx(n, n->y, n->x);
   if(n->x > 0){
     if(cell_double_wide_p(targ)){ // replaced cell is half of a wide char
-      cell* sacrifice = targ->gcluster == 0 ?
+      nccell* sacrifice = targ->gcluster == 0 ?
         // right half will never be on the first column of a row
         &n->fb[nfbcellidx(n, n->y, n->x - 1)] :
         // left half will never be on the last column of a row
@@ -1548,7 +1555,7 @@ ncplane_put(ncplane* n, int y, int x, const char* egc, int cols,
   }
 //fprintf(stderr, "%08x %016lx %c %d %d\n", targ->gcluster, targ->channels, cell_double_wide_p(targ) ? 'D' : 'd', bytes, cols);
   if(cols > 1){ // must set our right wide, and check for further damage
-    cell* candidate = &n->fb[nfbcellidx(n, n->y, n->x + 1)];
+    nccell* candidate = &n->fb[nfbcellidx(n, n->y, n->x + 1)];
     if(cell_wide_left_p(candidate)){
       cell_obliterate(n, &n->fb[nfbcellidx(n, n->y, n->x + 2)]);
     }
@@ -1560,7 +1567,7 @@ ncplane_put(ncplane* n, int y, int x, const char* egc, int cols,
   return cols;
 }
 
-int ncplane_putc_yx(ncplane* n, int y, int x, const cell* c){
+int ncplane_putc_yx(ncplane* n, int y, int x, const nccell* c){
   const int cols = cell_double_wide_p(c) ? 2 : 1;
   const char* egc = cell_extended_gcluster(n, c);
   return ncplane_put(n, y, x, egc, cols, c->stylemask, c->channels, strlen(egc));
@@ -1582,7 +1589,7 @@ int ncplane_putegc_yx(ncplane* n, int y, int x, const char* gclust, int* sbytes)
 int ncplane_putchar_stained(ncplane* n, char c){
   uint64_t channels = n->channels;
   uint32_t stylemask = n->stylemask;
-  const cell* targ = &n->fb[nfbcellidx(n, n->y, n->x)];
+  const nccell* targ = &n->fb[nfbcellidx(n, n->y, n->x)];
   n->channels = targ->channels;
   n->stylemask = targ->stylemask;
   int ret = ncplane_putchar(n, c);
@@ -1594,7 +1601,7 @@ int ncplane_putchar_stained(ncplane* n, char c){
 int ncplane_putwegc_stained(ncplane* n, const wchar_t* gclust, int* sbytes){
   uint64_t channels = n->channels;
   uint32_t stylemask = n->stylemask;
-  const cell* targ = &n->fb[nfbcellidx(n, n->y, n->x)];
+  const nccell* targ = &n->fb[nfbcellidx(n, n->y, n->x)];
   n->channels = targ->channels;
   n->stylemask = targ->stylemask;
   int ret = ncplane_putwegc(n, gclust, sbytes);
@@ -1606,7 +1613,7 @@ int ncplane_putwegc_stained(ncplane* n, const wchar_t* gclust, int* sbytes){
 int ncplane_putegc_stained(ncplane* n, const char* gclust, int* sbytes){
   uint64_t channels = n->channels;
   uint32_t stylemask = n->stylemask;
-  const cell* targ = &n->fb[nfbcellidx(n, n->y, n->x)];
+  const nccell* targ = &n->fb[nfbcellidx(n, n->y, n->x)];
   n->channels = targ->channels;
   n->stylemask = targ->stylemask;
   int ret = ncplane_putegc(n, gclust, sbytes);
@@ -1615,11 +1622,11 @@ int ncplane_putegc_stained(ncplane* n, const char* gclust, int* sbytes){
   return ret;
 }
 
-int ncplane_cursor_at(const ncplane* n, cell* c, char** gclust){
+int ncplane_cursor_at(const ncplane* n, nccell* c, char** gclust){
   if(n->y == n->leny && n->x == n->lenx){
     return -1;
   }
-  const cell* src = &n->fb[nfbcellidx(n, n->y, n->x)];
+  const nccell* src = &n->fb[nfbcellidx(n, n->y, n->x)];
   memcpy(c, src, sizeof(*src));
   if(cell_simple_p(c)){
     *gclust = NULL;
@@ -1738,7 +1745,7 @@ int ncplane_vprintf_stained(struct ncplane* n, const char* format, va_list ap){
   return ret;
 }
 
-int ncplane_hline_interp(ncplane* n, const cell* c, int len,
+int ncplane_hline_interp(ncplane* n, const nccell* c, int len,
                          uint64_t c1, uint64_t c2){
   unsigned ur, ug, ub;
   int r1, g1, b1, r2, g2, b2;
@@ -1758,7 +1765,7 @@ int ncplane_hline_interp(ncplane* n, const cell* c, int len,
   int deltbg = bg2 - bg1;
   int deltbb = bb2 - bb1;
   int ret;
-  cell dupc = CELL_TRIVIAL_INITIALIZER;
+  nccell dupc = CELL_TRIVIAL_INITIALIZER;
   if(cell_duplicate(n, &dupc, c) < 0){
     return -1;
   }
@@ -1790,7 +1797,7 @@ int ncplane_hline_interp(ncplane* n, const cell* c, int len,
   return ret;
 }
 
-int ncplane_vline_interp(ncplane* n, const cell* c, int len,
+int ncplane_vline_interp(ncplane* n, const nccell* c, int len,
                          uint64_t c1, uint64_t c2){
   unsigned ur, ug, ub;
   int r1, g1, b1, r2, g2, b2;
@@ -1811,7 +1818,7 @@ int ncplane_vline_interp(ncplane* n, const cell* c, int len,
   int deltbb = (bb2 - bb1) / (len + 1);
   int ret, ypos, xpos;
   ncplane_cursor_yx(n, &ypos, &xpos);
-  cell dupc = CELL_TRIVIAL_INITIALIZER;
+  nccell dupc = CELL_TRIVIAL_INITIALIZER;
   if(cell_duplicate(n, &dupc, c) < 0){
     return -1;
   }
@@ -1846,9 +1853,9 @@ int ncplane_vline_interp(ncplane* n, const cell* c, int len,
   return ret;
 }
 
-int ncplane_box(ncplane* n, const cell* ul, const cell* ur,
-                const cell* ll, const cell* lr, const cell* hl,
-                const cell* vl, int ystop, int xstop,
+int ncplane_box(ncplane* n, const nccell* ul, const nccell* ur,
+                const nccell* ll, const nccell* lr, const nccell* hl,
+                const nccell* vl, int ystop, int xstop,
                 unsigned ctlword){
   int yoff, xoff, ymax, xmax;
   ncplane_cursor_yx(n, &yoff, &xoff);
@@ -2192,6 +2199,18 @@ int (*ncplane_resizecb(const ncplane* n))(ncplane*){
   return n->resizecb;
 }
 
+int ncplane_resize_maximize(ncplane* n){
+  const ncpile* pile = ncplane_pile(n);
+  const int rows = pile->dimy;
+  const int cols = pile->dimx;
+  int oldy, oldx;
+  ncplane_dim_yx(n, &oldy, &oldx); // current dimensions of 'n'
+//fprintf(stderr, "CURRENT: %d/%d TERM: %d/%d\n", oldy, oldx, rows, cols);
+  int keepleny = oldy > rows ? rows : oldy;
+  int keeplenx = oldx > cols ? cols : oldx;
+  return ncplane_resize_internal(n, 0, 0, keepleny, keeplenx, 0, 0, rows, cols);
+}
+
 int ncplane_resize_realign(ncplane* n){
   const ncplane* parent = ncplane_parent_const(n);
   if(parent == n){ // somehow got stdplane, should never get here
@@ -2209,6 +2228,9 @@ int ncplane_resize_realign(ncplane* n){
 // The standard plane cannot be reparented; we return NULL in that case.
 // If provided |newparent|==|n|, we are moving |n| to its own stack. If |n|
 // is already bound to |newparent|, this is a no-op, and we return |n|.
+// This is essentially a wrapper around ncplane_reparent_family() that first
+// reparents any children to the parent of 'n', or makes them root planes if
+// 'n' is a root plane.
 ncplane* ncplane_reparent(ncplane* n, ncplane* newparent){
   if(n == ncplane_notcurses(n)->stdplane){
     return NULL; // can't reparent standard plane
@@ -2217,23 +2239,22 @@ ncplane* ncplane_reparent(ncplane* n, ncplane* newparent){
     return n;
   }
   if(n->blist){
-    // FIXME these both look to throw away siblings following n->blist :/
     if(n->boundto == n){ // children become new root planes
       for(ncplane* child = n->blist ; child ; child = child->bnext){
         child->boundto = child;
       }
-      /* FIXME FIXME FIXME
-      n->blist->bnext = ncplane_pile(n)->root;
-      n->blist->bnext->bprev = &n->blist->bnext;
-      n->blist->bprev = &ncplane_pile(n)->root;
-      ncplane_pile(n)->root = n->blist;
-      */
-    }else{ // children are rebound to current parent
-      if( (n->blist->bnext = n->boundto->blist) ){
-        n->boundto->blist->bprev = &n->blist->bnext;
+      if( (n->blist->bnext = ncplane_pile(n)->roots) ){
+        n->blist->bnext->bprev = &n->blist->bnext;
       }
-      n->blist->bprev = &n->boundto->blist;
-      n->boundto->blist = n->blist;
+      n->blist->bprev = &ncplane_pile(n)->roots;
+      ncplane_pile(n)->roots = n->blist;
+    }else{ // children are rebound to current parent
+      ncplane** plink = &n->boundto->blist;
+      while(*plink){
+        plink = &(*plink)->bnext;
+      }
+      n->blist->bprev = plink;
+      *plink = n->blist;
     }
     n->blist = NULL;
   }
@@ -2537,12 +2558,12 @@ char* ncplane_contents(const ncplane* nc, int begy, int begx, int leny, int lenx
 }
 
 int cells_ascii_box(struct ncplane* n, uint32_t attr, uint64_t channels,
-                    cell* ul, cell* ur, cell* ll, cell* lr, cell* hl, cell* vl){
+                    nccell* ul, nccell* ur, nccell* ll, nccell* lr, nccell* hl, nccell* vl){
   return cells_load_box(n, attr, channels, ul, ur, ll, lr, hl, vl, "/\\\\/-|");
 }
 
 int cells_double_box(struct ncplane* n, uint32_t attr, uint64_t channels,
-                     cell* ul, cell* ur, cell* ll, cell* lr, cell* hl, cell* vl){
+                     nccell* ul, nccell* ur, nccell* ll, nccell* lr, nccell* hl, nccell* vl){
   if(notcurses_canutf8(ncplane_notcurses(n))){
     return cells_load_box(n, attr, channels, ul, ur, ll, lr, hl, vl, "╔╗╚╝═║");
   }
@@ -2550,7 +2571,7 @@ int cells_double_box(struct ncplane* n, uint32_t attr, uint64_t channels,
 }
 
 int cells_rounded_box(struct ncplane* n, uint32_t attr, uint64_t channels,
-                      cell* ul, cell* ur, cell* ll, cell* lr, cell* hl, cell* vl){
+                      nccell* ul, nccell* ur, nccell* ll, nccell* lr, nccell* hl, nccell* vl){
   if(notcurses_canutf8(ncplane_notcurses(n))){
     return cells_load_box(n, attr, channels, ul, ur, ll, lr, hl, vl, "╭╮╰╯─│");
   }
@@ -2584,6 +2605,7 @@ int ncplane_putstr_yx(struct ncplane* n, int y, int x, const char* gclusters){
   while(*gclusters){
     int wcs;
     int cols = ncplane_putegc_yx(n, y, x, gclusters, &wcs);
+//fprintf(stderr, "wrote %.*s %d cols %d bytes now at %d/%d\n", wcs, gclusters, cols, wcs, n->y, n->x);
     if(cols < 0){
       return -ret;
     }
